@@ -9,5 +9,5 @@
 ## Quiet concerns of R CMD check. 
 ## Avoid this warning: no visible binding for global variable
 if(getRversion() >= "2.15.1"){
-	utils::globalVariables(c("curvetypes"));
+	utils::globalVariables("curvetypes");
 }
